@@ -556,18 +556,24 @@ get_mail_from_control (LPDISPATCH ctrl, bool *none_selected)
   if (ret==NULL)
   {
     auto retV = Mail::searchMailsByUUID(uid);
-    if (retV.empty())
+    if (!retV.empty())
       {
-        log_error ("%s:%s: Failed to find mail %p in map.",
+        ret = retV.front();
+      }
+    else
+      {
+        log_debug ("%s:%s: Failed to find mail %p in map.",
                   SRCNAME, __func__, mailitem);
       }
-    ret = retV.front();
+      TRACEPOINT;
   }
+  TRACEPOINT;
   xfree (uid);
-
+  TRACEPOINT;
   /* This release may have killed the Mail object we obtained earlier
    * if it was just a leftover mail in the ribbon. */
   gpgol_release (mailitem);
+  TRACEPOINT;
   if (!Mail::isValidPtr (ret))
     {
       log_err ("Mail was only valid for this context.");
@@ -846,7 +852,8 @@ HRESULT get_is_crypto_mail (LPDISPATCH ctrl, VARIANT *result)
   MY_MAIL_GETTER
 
   result->vt = VT_BOOL | VT_BYREF;
-  result->pboolVal = mail && ((mail->isSigned () &&!mail->isEncrypted()) || mail->realyDecryptedSuccessfully ()) ?
+  result->pboolVal = mail && !mail->isVdPostponed ()
+                 && ((mail->isSigned () &&!mail->isEncrypted ()) || mail->realyDecryptedSuccessfully ()) ?
                           &var_true : &var_false;
 
   TRACEPOINT;
@@ -858,7 +865,7 @@ HRESULT get_is_vd_postponed (LPDISPATCH ctrl, VARIANT *result)
   MY_MAIL_GETTER
 
   result->vt = VT_BOOL | VT_BYREF;
-  result->pboolVal = mail && (mail->isVdPostponed () ) ?
+  result->pboolVal = mail && (mail->isVdPostponed () && mail->isCryptoMail ()) ?
                           &var_true : &var_false;
 
   TRACEPOINT;
